poisson_CNN is a convolutional neural network model whih estimates the solution of the Poisson equation with four Dirichlet boundary conditions on rectangular grids of variable sizes.

[An article describing the performance of our model](https://arxiv.org/abs/1910.08613) is available on arXiv. [A separate repository of Jupyter notebooks](github.com/aligirayhanozbay/poisson_CNN_jupyter) to generate the results outlined in the article is available.

Installation requires CUDA set up to work with tensorflow-gpu version 2.0.0 or newer. To install, please simply run
```
pip install poisson_CNN
```

